pysubsonic.pysubsonic
=====================

.. currentmodule:: pysubsonic

.. autoclass:: pysubsonic

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~pysubsonic.__init__
      ~pysubsonic.create_playlist
      ~pysubsonic.do_request
      ~pysubsonic.do_search3
      ~pysubsonic.get_bad_salt
      ~pysubsonic.get_playlist_id_by_name
      ~pysubsonic.get_playlists
      ~pysubsonic.get_song_ids
      ~pysubsonic.make_bad_auth_params
      ~pysubsonic.parse_playlist_id
      ~pysubsonic.parse_search3
      ~pysubsonic.update_playlist
   
   

   
   
   